@@ -124,7 +124,8 @@ class UpdateManager(Gtk.Window):
         # Look for a new release in a thread
         self.meta_release = MetaRelease(
             self.options and self.options.devel_release,
-            self.options and self.options.use_proposed)
+            self.options and self.options.use_proposed,
+            self.options and self.options.debug)
 
     def begin_user_resizable(self, stored_width=0, stored_height=0):
         self.set_resizable(True)
