@@ -595,6 +595,8 @@ class UpdatesAvailable(InternalDialog):
         # replace all multiple spaces by newlines
         p = re.compile(r'\s\s+', re.MULTILINE)
         long_desc = p.sub("\n", long_desc)
+        long_desc = ("Package: %s\n%s" %
+                     (item.pkg.name, long_desc))
 
         # now do the changelog
         name = item.pkg.name
